#!/bin/bash 
#SBATCH -J parallel-example  # Job name
#SBATCH -o %x.o.%J           # Job output file
#SBATCH -e %x.e.%J           # Job error file
#SBATCH -p c_compute_mdi1    # partition name
#SBATCH --ntasks=4           # number of parallel processes (tasks)
#SBATCH --time=00:05:00      # time limit
#SBATCH --reservation=training
#SBATCH --account=scw1148    # project account code

module purge
module load python
module load parallel
module list

# Define srun arguments:
srun="srun -n1 -N1 --exclusive"
# --exclusive     ensures srun uses distinct CPUs for each job step
# -n1 -N1         allocates a single core to each task

# Define parallel arguments:
parallel="parallel -N 1 --delay .2 -j $SLURM_NTASKS --joblog parallel_joblog --resume"
# -N 1              is number of arguments to pass to each job
# --delay .2        prevents overloading the controlling node on short jobs
# -j $SLURM_NTASKS  is the number of concurrent tasks parallel runs, so number of CPUs allocated
# --joblog name     parallel's log file of tasks it has run
# --resume          parallel can use a joblog and this to continue an interrupted run (job resubmitted)

# Run the tasks:
$parallel "$srun ./example.py {1}" ::: {1..80}
# in this case, we are running a script named example.py, and passing it a single argument
# {1} is the first argument
# parallel uses ::: to separate options. Here {1..4} is a shell expansion defining the values for
# the first argument, but could be any shell command so parallel will run the example.py script
# for the numbers 1 through 4 
#
# as an example, the first job will be run like this:
#    srun -N1 -n1 --exclusive ./example.py arg1:0
